@@ -4,19 +4,21 @@ prediction.mca <-
 function(model, 
          data = find_data(model), 
          at = NULL, 
+         calculate_se = FALSE,
          ...) {
     
     # extract predicted values
     # setup data
-    out <- build_datalist(data, at = at)
-    for (i in seq_along(out)) {
-        tmp <- predict(model, 
-                       newdata = out[[i]], 
-                       ...)
-        out[[i]] <- cbind(out[[i]], tmp)
-        rm(tmp)
+    if (is.null(at)) {
+        out <- data
+    } else {
+        out <- build_datalist(data, at = at, as.data.frame = TRUE)
+        at_specification <- attr(out, "at_specification")
     }
-    pred <- do.call("rbind", out)
+    # calculate predictions
+    tmp <- predict(model, newdata = out, ...)
+    # cbind back together
+    pred <- make_data_frame(out, tmp)
     pred[["fitted"]] <- NA_real_
     pred[["se.fitted"]] <- NA_real_
     
@@ -24,7 +26,7 @@ function(model,
     structure(pred, 
               class = c("prediction", "data.frame"), 
               row.names = seq_len(nrow(pred)),
-              at = if (is.null(at)) at else names(at), 
+              at = if (is.null(at)) at else at_specification,
               model.class = class(model),
               type = NA_character_)
 }
